@@ -1,3 +1,3 @@
 # -*- coding: utf-8 -*- 
 from .version import __version__  # noqa
-from .subsync import main  # noqa
+from .ffsubsync import main  # noqa
